"""NordCrawl - batch crawler för nordisk företagsdata"""

__version__ = "0.1.1"
__author__ = "Gracestack AB"

from .crawlers.batch_crawler import BatchCrawler
from .extractors.company_extractor import SwedishCompanyExtractor
from .database.supabase_client import SupabaseManager
from .models.company import CompanyData, CrawlJob, ExtractionResult

__all__ = [
    "BatchCrawler",
    "SwedishCompanyExtractor", 
    "SupabaseManager",
    "CompanyData",
    "CrawlJob",
    "ExtractionResult"
]
