from setuptools import setup, find_packages

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

with open("requirements.txt", "r", encoding="utf-8") as fh:
    requirements = [line.strip() for line in fh if line.strip() and not line.startswith("#")]

setup(
    name="nordcrawl",
    version="0.1.1",
    author="Gracestack AB",
    author_email="info@gracestack.se",
    description="LLM-ready batch crawling for Nordic company data",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/gracestack/nordcrawl",
    packages=find_packages(where="src"),
    package_dir={"": "src"},
    classifiers=[
        "Development Status :: 4 - Beta",
        "Intended Audience :: Developers",
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        "Programming Language :: Python :: 3",
        "Programming Language :: Python :: 3.10",
        "Programming Language :: Python :: 3.11",
        "Programming Language :: Python :: 3.12",
    ],
    python_requires=">=3.10",
    install_requires=requirements,
    entry_points={
        "console_scripts": [
            "nordcrawl=src.api.cli:app",
        ],
    },
    include_package_data=True,
    zip_safe=False,
)
